Automation of Exploratory Testing
------------

This package provides CLI utility which is capable of executing forking tests, recording results, 
clustering the responses and outputting HTML report with all differences in the responses plotted on a chart.